@@ -1,14 +1,12 @@
 package Net::Curl;
 
 use strict;
-use warnings;
 use Exporter 'import';
 
-## no critic (ProhibitExplicitISA)
 our @ISA;
 our $VERSION;
 BEGIN {
-	$VERSION = '0.58_3';
+	$VERSION = '0.20';
 
 	my $loaded = 0;
 
@@ -23,7 +21,6 @@ BEGIN {
 		DynaLoader::bootstrap( __PACKAGE__ );
 		$loaded = 1;
 	};
-	## no critic (RequireCheckingReturnValueOfEval)
 	eval { $load_xs->() } if $INC{ "XSLoader.pm" };
 	eval { $load_dyna->() } if $INC{ "DynaLoader.pm" } and not $loaded;
 	unless ( $loaded ) {
@@ -32,7 +29,7 @@ BEGIN {
 	}
 }
 
-our @EXPORT_OK = grep { /^(?:LIB)?CURL/x } keys %{Net::Curl::};
+our @EXPORT_OK = grep /^(?:LIB)?CURL/, keys %{Net::Curl::};
 our %EXPORT_TAGS = ( constants => \@EXPORT_OK );
 
 1;
@@ -82,11 +79,11 @@ Returns libcurl version string.
  # libcurl/7.21.4 GnuTLS/2.10.4 zlib/1.2.5 c-ares/1.7.4 ...
  print $libcurl_verstr;
 
-Calls L<curl_version(3)|https://curl.haxx.se/libcurl/c/curl_version.html> function.
+Calls L<curl_version(3)> function.
 
 =item version_info
 
-Returns a hashref with the same information as L<curl_version_info(3)|https://curl.haxx.se/libcurl/c/curl_version_info.html>.
+Returns a hashref with the same information as L<curl_version_info(3)>.
 
  my $libcurl_ver = Net::Curl::version_info();
  print Dumper( $libcurl_ver );
@@ -128,7 +125,7 @@ Decodes date string returning its numerical value, in seconds.
  print "$timestr\n";
  # Sun Nov  6 08:49:37 1994
 
-See L<curl_getdate(3)|https://curl.haxx.se/libcurl/c/curl_getdate.html> for more info on supported input formats.
+See L<curl_getdate(3)> for more info on supported input formats.
 
 =back
 
@@ -138,7 +135,7 @@ See L<curl_getdate(3)|https://curl.haxx.se/libcurl/c/curl_getdate.html> for more
 
 =item CURL_VERSION_* and CURLVERSION_*
 
-Can be used for decoding version_info() values. L<curl_version_info(3)|https://curl.haxx.se/libcurl/c/curl_version_info.html>
+Can be used for decoding version_info() values. L<curl_version_info(3)>
 
 =item LIBCURL_*
 
@@ -168,7 +165,7 @@ and a long list of contributors. However, currently it shares no common code.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2011-2015 Przemyslaw Iskra.
+Copyright (c) 2011 Przemyslaw Iskra.
 
 You may opt to use, copy, modify, merge, publish, distribute and/or sell
 copies of the Software, and permit persons to whom the Software is furnished
@@ -182,5 +179,3 @@ L<Net::Curl::Compat>
 L<Net::Curl::examples>
 L<http://curl.haxx.se>
 L<libcurl(3)>
-
-=cut
