@@ -58,66 +58,22 @@ methods that do not yet form part of official WWW::Curl distribution.
 use strict;
 use warnings;
 
-use Carp qw(croak);
-
-our $VERSION = 4.15;
-
-=for Pod::Coverage
-VERSION
-=cut
-
-# Dirty hack so Test::ConsistentVersion passes
-sub VERSION {
-	return (caller)[0] eq 'Test::ConsistentVersion'
-		? '0.58_3'
-		: $VERSION;
-}
-
-my %packages = (
-	'WWW/Curl.pm' => 0,
-	'WWW/Curl/Easy.pm' => 420,
-	'WWW/Curl/Form.pm' => 4289,
-	'WWW/Curl/Multi.pm' => 5193,
-	'WWW/Curl/Share.pm' => 6272,
+my @packages = qw(
+	WWW/Curl.pm
+	WWW/Curl/Easy.pm
+	WWW/Curl/Form.pm
+	WWW/Curl/Multi.pm
+	WWW/Curl/Share.pm
 );
 
-my $start = tell *DATA;
-unshift @INC, sub {
-	my $pkg = $packages{ $_[1] };
-	return unless defined $pkg;
-	## no critic (RequireUseOfExceptions)
-	open(my $fh, '<&', *DATA) or croak "can't read from __DATA__";
-	seek $fh, $start + $pkg, 0;
-	return $fh;
-};
-
-1;
-
-=head1 COPYRIGHT
-
-Copyright (c) 2011-2015 Przemyslaw Iskra <sparky at pld-linux.org>.
-
-You may opt to use, copy, modify, merge, publish, distribute and/or sell
-copies of the Software, and permit persons to whom the Software is furnished
-to do so, under the terms of the MPL or the MIT/X-derivate licenses. You may
-pick one of these licenses.
-
-=cut
-
-__DATA__
-package WWW::Curl;
-
-use strict;
-use warnings;
-use Net::Curl ();
-
-our $VERSION = 4.15;
+# mark fake packages as loaded
+@INC{ @packages } = ("Net::Curl::Compat") x scalar @packages;
 
 # copies constants to current namespace
 sub _copy_constants
 {
 	my $EXPORT = shift;
-	my $dest = (shift) . "::";
+	my $dest = shift;
 	my $source = shift;
 
 	no strict 'refs';
@@ -125,75 +81,80 @@ sub _copy_constants
 	push @$EXPORT, @constants;
 
 	foreach my $name ( @constants ) {
-		*{ $dest . $name } = \*{ $source . $name };
+		*{ $dest . $name } = \*{ $source . $name};
 	}
 }
 
-1;
 
-__END__
 
-package WWW::Curl::Easy;
-
-use strict;
-use warnings;
-use WWW::Curl ();
-use Net::Curl::Easy ();
+use Net::Curl ();
+use Net::Curl::Easy qw(/^CURLOPT_/ CURLE_BAD_FUNCTION_ARGUMENT CURLINFO_PRIVATE);
+use Net::Curl::Form qw(/^CURLFORM_/);
+use Net::Curl::Share ();
+use Net::Curl::Multi ();
 use Exporter ();
-our @ISA = qw(Net::Curl::Easy Exporter);
 
-our $VERSION = 4.15;
-our @EXPORT;
+# WWW::Curl
+
+$WWW::Curl::VERSION = '4.15';
+
+
+# WWW::Curl::Easy
+
+@WWW::Curl::Easy::ISA = qw(Net::Curl::Easy Exporter);
+$WWW::Curl::Easy::VERSION = '4.15';
 
 BEGIN {
+	my $e = [];
 	# in WWW::Curl almost all the constants are thrown into WWW::Curl::Easy
 	foreach my $pkg ( qw(Net::Curl:: Net::Curl::Easy::
 			Net::Curl::Form:: Net::Curl::Share::
 			Net::Curl::Multi::) ) {
-		WWW::Curl::_copy_constants(
-			\@EXPORT, __PACKAGE__, $pkg );
+		Net::Curl::Compat::_copy_constants(
+			$e, 'WWW::Curl::Easy::', $pkg );
 	}
+	@WWW::Curl::Easy::EXPORT = @$e;
 }
 
 # what is that anyways ?
 $WWW::Curl::Easy::headers = "";
 $WWW::Curl::Easy::content = "";
 
-sub new
+sub WWW::Curl::Easy::new
 {
-	my $class = shift || __PACKAGE__;
-	return $class->SUPER::new();
+	my $class = shift || 'WWW::Curl::Easy';
+	return Net::Curl::Easy::new( $class );
 }
 
-*init = \&new;
-*errbuf = \&Net::Curl::Easy::error;
-*strerror = \&Net::Curl::Easy::strerror;
+*WWW::Curl::Easy::init = \&WWW::Curl::Easy::new;
+*WWW::Curl::Easy::errbuf = \&Net::Curl::Easy::error;
+*WWW::Curl::Easy::strerror = \&Net::Curl::Easy::strerror;
 
-*version = \&Net::Curl::version;
+*WWW::Curl::Easy::version = \&Net::Curl::version;
 
-sub cleanup { 0 };
+sub WWW::Curl::Easy::cleanup { 0 };
 
-sub internal_setopt { die };
+sub WWW::Curl::Easy::internal_setopt { die };
 
-sub duphandle
+sub WWW::Curl::Easy::duphandle
 {
 	my ( $source ) = @_;
-	my $clone = $source->SUPER::duphandle;
+	my $clone = Net::Curl::Easy::duphandle( $source );
 	bless $clone, "WWW::Curl::Easy"
 }
 
-sub const_string
+sub WWW::Curl::Easy::const_string
 {
 	my ( $self, $constant ) = @_;
-	return constant( $constant );
+	return WWW::Curl::Easy::constant( $constant );
 }
 
 # this thing is weird !
-sub constant
+sub WWW::Curl::Easy::constant
 {
 	my $name = shift;
 	undef $!;
-	my $value = eval "$name()";
+	my $value = eval "WWW::Curl::Easy::$name()";
 	if ( $@ ) {
 		require POSIX;
 		$! = POSIX::EINVAL();
@@ -202,7 +163,7 @@ sub constant
 	return $value;
 }
 
-sub setopt
+sub WWW::Curl::Easy::setopt
 {
 	# convert options and provide wrappers for callbacks
 	my ($self, $option, $value, $push) = @_;
@@ -254,18 +215,18 @@ sub setopt
 		};
 	}
 	eval {
-		$self->SUPER::setopt( $option, $value );
+		Net::Curl::Easy::setopt( $self, $option, $value );
 	};
 	return 0 unless $@;
 	return 0+$@ if ref $@ eq "Net::Curl::Easy::Code";
 	die $@;
 }
 
-sub pushopt
+sub WWW::Curl::Easy::pushopt
 {
 	my ($self, $option, $value) = @_;
 	eval {
-		$self->SUPER::pushopt( $option, $value );
+		Net::Curl::Easy::pushopt( $self, $option, $value );
 	};
 	return 0 unless $@;
 	if ( ref $@ eq "Net::Curl::Easy::Code" ) {
@@ -278,7 +239,7 @@ sub pushopt
 	die $@;
 }
 
-sub getinfo
+sub WWW::Curl::Easy::getinfo
 {
 	my ($self, $option) = @_;
 
@@ -287,7 +248,7 @@ sub getinfo
 		$ret = $self->{private};
 	} else {
 		eval {
-			$ret = $self->SUPER::getinfo( $option );
+			$ret = Net::Curl::Easy::getinfo( $self, $option );
 		};
 		if ( $@ ) {
 			return undef if ref $@ eq "Net::Curl::Easy::Code";
@@ -300,11 +261,11 @@ sub getinfo
 	return $ret;
 }
 
-sub perform
+sub WWW::Curl::Easy::perform
 {
 	my $self = shift;
 	eval {
-		$self->SUPER::perform( @_ );
+		Net::Curl::Easy::perform( $self );
 	};
 	if ( defined $self->{errorbuffer} ) {
 		my $error = $self->error();
@@ -322,34 +283,25 @@ sub perform
 	die $@;
 }
 
-1;
 
-__END__
+# WWW::Curl::Form
 
-package WWW::Curl::Form;
-
-use strict;
-use warnings;
-use WWW::Curl ();
-use Net::Curl::Form ();
-use Exporter ();
-our @ISA = qw(Net::Curl::Form Exporter);
-
-our $VERSION = 4.15;
-
-our @EXPORT;
+@WWW::Curl::Form::ISA = qw(Net::Curl::Form Exporter);
+$WWW::Curl::Form::VERSION = '4.15';
 
 BEGIN {
-	WWW::Curl::_copy_constants(
-		\@EXPORT, __PACKAGE__, "Net::Curl::Form::" );
+	@WWW::Curl::Form::EXPORT = ();
+	Net::Curl::Compat::_copy_constants(
+		\@WWW::Curl::Form::EXPORT, 'WWW::Curl::Form::',
+		"Net::Curl::Form::" );
 }
 
 # this thing is weird !
-sub constant
+sub WWW::Curl::Form::constant
 {
 	my $name = shift;
 	undef $!;
-	my $value = eval "$name()";
+	my $value = eval "WWW::Curl::Form::$name()";
 	if ( $@ ) {
 		require POSIX;
 		$! = POSIX::EINVAL();
@@ -358,13 +310,13 @@ sub constant
 	return $value;
 }
 
-sub new
+sub WWW::Curl::Form::new
 {
-	my $class = shift || __PACKAGE__;
-	return $class->SUPER::new();
+	my $class = shift || 'WWW::Curl::Form';
+	return Net::Curl::Form::new( $class );
 }
 
-sub formadd
+sub WWW::Curl::Form::formadd
 {
 	my ( $self, $name, $value ) = @_;
 	eval {
@@ -375,7 +327,7 @@ sub formadd
 	};
 }
 
-sub formaddfile
+sub WWW::Curl::Form::formaddfile
 {
 	my ( $self, $filename, $description, $type ) = @_;
 	eval {
@@ -387,48 +339,41 @@ sub formaddfile
 	};
 }
 
-1;
 
-__END__
+# WWW::Curl::Multi
 
-package WWW::Curl::Multi;
+@WWW::Curl::Multi::ISA = qw(Net::Curl::Multi);
 
-use strict;
-use warnings;
-use WWW::Curl ();
-use Net::Curl::Multi ();
-our @ISA = qw(Net::Curl::Multi);
+*WWW::Curl::Multi::strerror = \&Net::Curl::Multi::strerror;
 
-*strerror = \&Net::Curl::Multi::strerror;
-
-sub new
+sub WWW::Curl::Multi::new
 {
-	my $class = shift || __PACKAGE__;
-	return $class->SUPER::new();
+	my $class = shift || 'WWW::Curl::Multi';
+	return Net::Curl::Multi::new( $class );
 }
 
-sub add_handle
+sub WWW::Curl::Multi::add_handle
 {
 	my ( $multi, $easy ) = @_;
 	eval {
-		$multi->SUPER::add_handle( $easy );
+		Net::Curl::Multi::add_handle( $multi, $easy );
 	};
 }
 
-sub remove_handle
+sub WWW::Curl::Multi::remove_handle
 {
 	my ( $multi, $easy ) = @_;
 	eval {
-		$multi->SUPER::remove_handle( $easy );
+		Net::Curl::Multi::remove_handle( $multi, $easy );
 	};
 }
 
-sub info_read
+sub WWW::Curl::Multi::info_read
 {
 	my ( $multi ) = @_;
 	my @ret;
 	eval {
-		@ret = $multi->SUPER::info_read();
+		@ret = Net::Curl::Multi::info_read( $multi );
 	};
 	return () unless @ret;
 
@@ -438,12 +383,12 @@ sub info_read
 	return ( $easy->{private}, $result );
 }
 
-sub fdset
+sub WWW::Curl::Multi::fdset
 {
 	my ( $multi ) = @_;
 	my @vec;
 	eval {
-		@vec = $multi->SUPER::fdset;
+		@vec = Net::Curl::Multi::fdset( $multi );
 	};
 	my @out;
 	foreach my $in ( @vec ) {
@@ -458,52 +403,43 @@ sub fdset
 	return @out;
 }
 
-sub perform
+sub WWW::Curl::Multi::perform
 {
 	my ( $multi ) = @_;
 
 	my $ret;
 	eval {
-		$ret = $multi->SUPER::perform;
+		$ret = Net::Curl::Multi::perform( $multi );
 	};
 
 	return $ret;
 }
 
-1;
+# WWW::Curl::Share
 
-__END__
-
-package WWW::Curl::Share;
-
-use strict;
-use warnings;
-use WWW::Curl ();
-use Net::Curl::Share ();
-use Exporter ();
-our @ISA = qw(Net::Curl::Share Exporter);
-
-our @EXPORT;
+@WWW::Curl::Share::ISA = qw(Net::Curl::Share Exporter);
 
 BEGIN {
-	WWW::Curl::_copy_constants(
-		\@EXPORT, __PACKAGE__, "Net::Curl::Share::" );
+	@WWW::Curl::Share::EXPORT = ();
+	Net::Curl::Compat::_copy_constants(
+		\@WWW::Curl::Share::EXPORT, 'WWW::Curl::Share::',
+		"Net::Curl::Share::" );
 }
 
-*strerror = \&Net::Curl::Share::strerror;
+*WWW::Curl::Share::strerror = \&Net::Curl::Share::strerror;
 
-sub new
+sub WWW::Curl::Share::new
 {
-	my $class = shift || __PACKAGE__;
-	return $class->SUPER::new();
+	my $class = shift || 'WWW::Curl::Share';
+	return Net::Curl::Share::new( $class );
 }
 
 # this thing is weird !
-sub constant
+sub WWW::Curl::Share::constant
 {
 	my $name = shift;
 	undef $!;
-	my $value = eval "$name()";
+	my $value = eval "WWW::Curl::Share::$name()";
 	if ( $@ ) {
 		require POSIX;
 		$! = POSIX::EINVAL();
@@ -512,18 +448,24 @@ sub constant
 	return $value;
 }
 
-sub setopt
+sub WWW::Curl::Share::setopt
 {
 	my ($self, $option, $value) = @_;
 	eval {
-		$self->SUPER::setopt( $option, $value );
+		Net::Curl::Share::setopt( $self, $option, $value );
 	};
 	return 0 unless $@;
-	return 0+$@ if ref $@ eq "Net::Curl::Share::Code";
+	return 0+$@ if ref $@ eq "Net::Curl::Form::Code";
 	die $@;
 }
 
 1;
 
-__END__
+=head1 COPYRIGHT
 
+Copyright (c) 2011 Przemyslaw Iskra <sparky at pld-linux.org>.
+
+You may opt to use, copy, modify, merge, publish, distribute and/or sell
+copies of the Software, and permit persons to whom the Software is furnished
+to do so, under the terms of the MPL or the MIT/X-derivate licenses. You may
+pick one of these licenses.
