@@ -5,12 +5,11 @@ use warnings;
 use Net::Curl ();
 use Exporter 'import';
 
-our $VERSION = '0.58_3';
+*VERSION = \*Net::Curl::VERSION;
 
-our @EXPORT_OK = grep { /^CURL/x } keys %{Net::Curl::Easy::};
+our @EXPORT_OK = grep /^CURL/, keys %{Net::Curl::Easy::};
 our %EXPORT_TAGS = ( constants => \@EXPORT_OK );
 
-## no critic (ProhibitMultiplePackages)
 package Net::Curl::Easy::Code;
 
 use overload
@@ -91,7 +90,7 @@ object.
 
  my $easy = Net::Curl::Easy->new( [qw(my very private data)] );
 
-Calls L<curl_easy_init(3)|https://curl.haxx.se/libcurl/c/curl_easy_init.html> and presets some defaults.
+Calls L<curl_easy_init(3)> and presets some defaults.
 
 =back
 
@@ -109,7 +108,7 @@ If you want it copied you must do it on your own.
  use Storable qw(dclone);
  my $deep_clone = $easy->duphandle( dclone( $easy ) );
 
-Calls L<curl_easy_duphandle(3)|https://curl.haxx.se/libcurl/c/curl_easy_duphandle.html>.
+Calls L<curl_easy_duphandle(3)>.
 
 =item setopt( OPTION, VALUE )
 
@@ -118,7 +117,7 @@ VALUE depends on whatever that option expects.
 
  $easy->setopt( Net::Curl::Easy::CURLOPT_URL, $uri );
 
-Calls L<curl_easy_setopt(3)|https://curl.haxx.se/libcurl/c/curl_easy_setopt.html>. Throws L</Net::Curl::Easy::Code> on error.
+Calls L<curl_easy_setopt(3)>. Throws L</Net::Curl::Easy::Code> on error.
 
 =item pushopt( OPTION, ARRAYREF )
 
@@ -128,16 +127,16 @@ replacing the old slist.
  $easy->pushopt( Net::Curl::Easy::CURLOPT_HTTPHEADER,
      ['More: headers'] );
 
-Builds a slist and calls L<curl_easy_setopt(3)|https://curl.haxx.se/libcurl/c/curl_easy_setopt.html>.
+Builds a slist and calls L<curl_easy_setopt(3)>.
 Throws L</Net::Curl::Easy::Code> on error.
 
 =item reset( )
 
-Reinitializes easy handle B<(was broken before v0.27!)>.
+Reinitializes easy handle.
 
  $easy->reset();
 
-Calls L<curl_easy_reset(3)|https://curl.haxx.se/libcurl/c/curl_easy_reset.html> and presets some defaults.
+Calls L<curl_easy_reset(3)> and presets some defaults.
 
 =item perform( )
 
@@ -145,7 +144,7 @@ Perform upload and download process.
 
  $easy->perform();
 
-Calls L<curl_easy_perform(3)|https://curl.haxx.se/libcurl/c/curl_easy_perform.html>. Rethrows exceptions from callbacks.
+Calls L<curl_easy_perform(3)>. Rethrows exceptions from callbacks.
 Throws L</Net::Curl::Easy::Code> on other errors.
 
 =item getinfo( OPTION )
@@ -154,17 +153,14 @@ Retrieve a value. OPTION is one of C<CURLINFO_*> constants.
 
  my $socket = $self->getinfo( CURLINFO_LASTSOCKET );
 
-Calls L<curl_easy_getinfo(3)|https://curl.haxx.se/libcurl/c/curl_easy_getinfo.html>.
+Calls L<curl_easy_getinfo(3)>.
 Throws L</Net::Curl::Easy::Code> on error.
 
-In the case of C<CURLINFO_CERTINFO>, the return is an array reference of
-hash references; each hash represents one certificate.
-
 =item pause( )
 
 Pause the transfer.
 
-Calls L<curl_easy_pause(3)|https://curl.haxx.se/libcurl/c/curl_easy_pause.html>. Not available in curl before 7.18.0.
+Calls L<curl_easy_pause(3)>. Not available in curl before 7.18.0.
 Throws L</Net::Curl::Easy::Code> on error.
 
 =item send( BUFFER )
@@ -173,7 +169,7 @@ Send raw data.
 
  $easy->send( $data );
 
-Calls L<curl_easy_send(3)|https://curl.haxx.se/libcurl/c/curl_easy_send.html>. Not available in curl before 7.18.2.
+Calls L<curl_easy_send(3)>. Not available in curl before 7.18.2.
 Throws L</Net::Curl::Easy::Code> on error.
 
 =item recv( BUFFER, MAXLENGTH )
@@ -183,14 +179,14 @@ concatenated to BUFFER.
 
  $easy->recv( $buffer, $len );
 
-Calls L<curl_easy_recv(3)|https://curl.haxx.se/libcurl/c/curl_easy_recv.html>. Not available in curl before 7.18.2.
+Calls L<curl_easy_recv(3)>. Not available in curl before 7.18.2.
 Throws L</Net::Curl::Easy::Code> on error.
 
 =item error( )
 
 Get last error message.
 
-See information on C<CURLOPT_ERRORBUFFER> in L<curl_easy_setopt(3)|https://curl.haxx.se/libcurl/c/curl_easy_setopt.html> for
+See information on C<CURLOPT_ERRORBUFFER> in L<curl_easy_setopt(3)> for
 a longer description.
 
  my $error = $easy->error();
@@ -223,25 +219,6 @@ form object.
 
 Use setopt() with CURLOPT_HTTPPOST option to attach the share object.
 
-=item escape( )
-
-URL encodes the given string.
-
- my $escaped = $easy->escape( "+foo" );
-
-Calls L<curl_easy_escape(3)|https://curl.haxx.se/libcurl/c/curl_easy_escape.html> which URL encode the given string.
-
-=item unescape( )
-
-URL decodes the given string.
-
- my $unescaped = $easy->unescape( "%2Bbar" );
-
-Calls L<curl_easy_unescape(3)|https://curl.haxx.se/libcurl/c/curl_easy_unescape.html> which URL decodes the given string.
-
-If you are sure the unescaped data contains a utf8 string, you can mark it
-with utf8::decode( $unescaped )
-
 =back
 
 =head2 FUNCTIONS
@@ -258,7 +235,7 @@ Return a string for error code CODE.
      Net::Curl::Easy::CURLE_OK
  );
 
-Calls L<curl_easy_strerror(3)|https://curl.haxx.se/libcurl/c/curl_easy_strerror.html>.
+Calls L<curl_easy_strerror(3)>.
 
 =back
 
@@ -278,7 +255,7 @@ base object.
 =item CURLOPT_ERRORBUFFER
 
 setopt() does not allow to use this constant. You can always retrieve latest
-error message with $easy->error() method.
+error message with $east->error() method.
 
 =back
 
@@ -360,13 +337,12 @@ CURL_SEEKFUNC_* values.
 =item CURLOPT_SOCKOPTFUNCTION ( CURLOPT_SOCKOPTDATA ) 7.15.6+
 
 sockopt callback receives 4 arguments: easy object, socket fd, socket purpose,
-and CURLOPT_SOCKOPTDATA value. Is should return one of CURL_SOCKOPT_*
-values.
+and CURLOPT_SOCKOPTDATA value. Should return 0 on success.
 
  sub cb_sockopt {
      my ( $easy, $socket, $purpose, $uservar ) = @_;
      # ... do something with the socket ...
-     return CURL_SOCKOPT_OK;
+     return 0;
  }
 
 =item CURLOPT_OPENSOCKETFUNCTION ( CURLOPT_OPENSOCKETDATA ) 7.17.1+
@@ -374,40 +350,19 @@ values.
 opensocket callback receives 4 arguments: easy object, socket purpose,
 address structure (in form of a hashref), and CURLOPT_OPENSOCKETDATA value.
 The address structure has following numeric values: "family", "socktype",
-"protocol"; and "addr" in binary form. Use Socket module to
-decode "addr" field. You are also allowed to change those values.
-
-Callback must return fileno of the socket or CURL_SOCKET_BAD on error.
+"protocol", "addrlen"; and "addr" in binary form. Use Socket CPAN module to
+decode "addr" field.
 
  use Socket;
  sub cb_opensocket {
      my ( $easy, $purpose, $address, $uservar ) = @_;
-
-     # decode addr information
-     my ( $port, $ip ) = unpack_sockaddr_in( $address->{addr} );
-     my $ip_string = inet_ntoa( $ip );
-
-     # open the socket
-     socket my $socket, $address->{family}, $address->{socktype},
-         $address->{protocol};
-
-     # save it somewhere so perl won't close the socket
-     $opened_sockets{ fileno( $socket ) } = $socket;
-
-     # return the socket
-     return fileno $socket;
+     my $addr = unpack_sockaddr_in( $address->{addr} );
+     # ... open ...
+     return $socket;
  }
 
-=item CURLOPT_CLOSESOCKETFUNCTION ( CURLOPT_CLOSESOCKETDATA ) 7.21.7+
-
-closesocket callback receives 3 arguments: easy object, socket fileno,
-and CURLOPT_CLOSESOCKETDATA value.
-
- sub cb_closesocket {
-     my ( $easy, $fileno, $uservar ) = @_;
-     my $socket = delete $opened_sockets{ $fileno };
-     close $socket;
- }
+Currently Net::Curl does not honour any changes made to $address, this
+may be fixed some day.
 
 =item CURLOPT_PROGRESSFUNCTION ( CURLOPT_PROGRESSDATA )
 
@@ -420,19 +375,6 @@ ulnow and CURLOPT_PROGRESSDATA value. It should return 0.
      return 0;
  }
 
-Since CURLOPT_XFERINFODATA is an alias to CURLOPT_PROGRESSDATA,
-they both set the same callback data for both
-CURLOPT_PROGRESSFUNCTION and CURLOPT_PROGRESSFUNCTION callbacks.
-
-=item CURLOPT_XFERINFOFUNCTION ( CURLOPT_XFERINFODATA ) 7.32.0+
-
-Works exactly like CURLOPT_PROGRESSFUNCTION callback, except that dltotal, dlnow, ultotal
-and ulnow are now integer values instead of double.
-
-Since CURLOPT_XFERINFODATA is an alias to CURLOPT_PROGRESSDATA,
-they both set the same callback data for both
-CURLOPT_PROGRESSFUNCTION and CURLOPT_PROGRESSFUNCTION callbacks.
-
 =item CURLOPT_HEADERFUNCTION ( CURLOPT_WRITEHEADER )
 
 Behaviour is the same as in write callback. Callback is called once for
@@ -504,17 +446,6 @@ CURLOPT_FNMATCH_DATA value. Must return one of CURL_FNMATCHFUNC_* values.
          : CURL_FNMATCHFUNC_NOMATCH );
  }
 
-=item CURLOPT_SSH_KEYFUNCTION ( CURLOPT_SSH_KEYDATA ) 7.19.6+
-
-sshkey callback receives 4 arguments: easy object, known key, found key,
-khmatch status and CURLOPT_SSH_KEYDATA value.
-Must return one of CURLKHSTAT_* values.
-
- sub cb_sshkey {
-     my ( $easy, $knownkey, $foundkey, $khmatch, $uservar ) = @_;
-     return CURLKHSTAT_FINE_ADD_TO_FILE;
- }
-
 =back
 
 =head2 Net::Curl::Easy::Code
@@ -547,11 +478,9 @@ L<libcurl-errors(3)>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2011-2015 Przemyslaw Iskra <sparky at pld-linux.org>.
+Copyright (c) 2011 Przemyslaw Iskra <sparky at pld-linux.org>.
 
 You may opt to use, copy, modify, merge, publish, distribute and/or sell
 copies of the Software, and permit persons to whom the Software is furnished
 to do so, under the terms of the MPL or the MIT/X-derivate licenses. You may
 pick one of these licenses.
-
-=cut
