@@ -5,27 +5,26 @@ use warnings;
 use Net::Curl ();
 use Exporter 'import';
 
-our $VERSION = '0.58_3';
+*VERSION = \*Net::Curl::VERSION;
 
-our @EXPORT_OK = grep { /^CURL/x } keys %{Net::Curl::Form::};
+our @EXPORT_OK = grep /^CURL/, keys %{Net::Curl::Form::};
 our %EXPORT_TAGS = ( constants => \@EXPORT_OK );
 
 sub strerror
 {
 	# first arg may be an object, package, or nothing
-	my (undef, $code) = @_;
+	my $code = pop @_;
 
-	foreach my $c ( grep { /^CURL_FORMADD_/x } keys %{Net::Curl::Form::} ) {
+	foreach my $c ( grep /^CURL_FORMADD_/, keys %{Net::Curl::Form::} ) {
 		next unless Net::Curl::Form->$c() == $code;
 		local $_ = $c;
-		s/^CURL_FORMADD_//x;
+		s/^CURL_FORMADD_//;
 		tr/_/ /;
 		return ucfirst lc $_;
 	}
 	return "Invalid formadd error code";
 }
 
-## no critic (ProhibitMultiplePackages)
 package Net::Curl::Form::Code;
 
 use overload
@@ -96,7 +95,7 @@ object.
 
 =item add( CURLFORM_option => DATA, ... )
 
-Adds new section to form object. See L<curl_formadd(3)|https://curl.haxx.se/libcurl/c/curl_formadd.html> for more info.
+Adds new section to form object. See L<curl_formadd(3)> for more info.
 
 Unlike in libcurl function, there is no need to add CURLFORM_END as the last
 argument.
@@ -200,7 +199,7 @@ serialization will be aborted.
 
 =back
 
-Calls L<curl_formget(3)|https://curl.haxx.se/libcurl/c/curl_formget.html>. Rethrows exceptions from callbacks.
+Calls L<curl_formget(3)>. Rethrows exceptions from callbacks.
 
 =back
 
@@ -229,7 +228,7 @@ String is extracted from error constant name.
 
 Most of those constants can be used in add() method. Currently CURLFORM_STREAM
 and CURLFORM_ARRAY are not supported. Others will behave in the way described
-in L<curl_formadd(3)|https://curl.haxx.se/libcurl/c/curl_formadd.html>.
+in L<curl_formadd(3)>.
 
 =item CURL_FORMADD_*
 
@@ -251,15 +250,13 @@ function to display a nice message.
 
 L<Net::Curl>
 L<Net::Curl::Easy>
-L<curl_formadd(3)|https://curl.haxx.se/libcurl/c/curl_formadd.html>
+L<curl_formadd(3)>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2011-2015 Przemyslaw Iskra <sparky at pld-linux.org>.
+Copyright (c) 2011 Przemyslaw Iskra <sparky at pld-linux.org>.
 
 You may opt to use, copy, modify, merge, publish, distribute and/or sell
 copies of the Software, and permit persons to whom the Software is furnished
 to do so, under the terms of the MPL or the MIT/X-derivate licenses. You may
 pick one of these licenses.
-
-=cut
