@@ -5,12 +5,11 @@ use warnings;
 use Net::Curl ();
 use Exporter 'import';
 
-our $VERSION = '0.58_3';
+*VERSION = \*Net::Curl::VERSION;
 
-our @EXPORT_OK = grep { /^CURL/x } keys %{Net::Curl::Multi::};
+our @EXPORT_OK = grep /^CURL/, keys %{Net::Curl::Multi::};
 our %EXPORT_TAGS = ( constants => \@EXPORT_OK );
 
-## no critic (ProhibitMultiplePackages)
 package Net::Curl::Multi::Code;
 
 use overload
@@ -73,7 +72,7 @@ object.
 
  my $multi = Net::Curl::Multi->new( [qw(my very private data)] );
 
-Calls L<curl_multi_init(3)|https://curl.haxx.se/libcurl/c/curl_multi_init.html> and presets some defaults.
+Calls L<curl_multi_init(3)> and presets some defaults.
 
 =back
 
@@ -87,7 +86,7 @@ Add Net::Curl::Easy to this Net::Curl::Multi object.
 
  $multi->add_handle( $easy );
 
-Calls L<curl_multi_add_handle(3)|https://curl.haxx.se/libcurl/c/curl_multi_add_handle.html>.
+Calls L<curl_multi_add_handle(3)>.
 Throws L</Net::Curl::Multi::Code> on error.
 
 =item remove_handle( EASY )
@@ -96,7 +95,7 @@ Remove Net::Curl::Easy from this Net::Curl::Multi object.
 
  $multi->remove_handle( $easy );
 
-Calls L<curl_multi_remove_handle(3)|https://curl.haxx.se/libcurl/c/curl_multi_remove_handle.html>.
+Calls L<curl_multi_remove_handle(3)>.
 Rethrows exceptions from callbacks.
 Throws L</Net::Curl::Multi::Code> on error.
 
@@ -110,7 +109,7 @@ $msg contains one of CURLMSG_* values, currently only CURLMSG_DONE is returned.
 $easy is the L<Net::Curl::Easy> object. Result is a
 L<Net::Curl::Easy::Code> dualvar object.
 
-Calls L<curl_multi_info_read(3)|https://curl.haxx.se/libcurl/c/curl_multi_info_read.html>.
+Calls L<curl_multi_info_read(3)>.
 
 =item fdset( )
 
@@ -119,7 +118,7 @@ L<select()|perlfunc/select> and L<vec()|perlfunc/vec> perl builtins.
 
  my ( $rvec, $wvec, $evec ) = $multi->fdset();
 
-Calls L<curl_multi_fdset(3)|https://curl.haxx.se/libcurl/c/curl_multi_fdset.html>.
+Calls L<curl_multi_fdset(3)>.
 Throws L</Net::Curl::Multi::Code> on error.
 
 =item timeout( )
@@ -128,7 +127,7 @@ Returns timeout value in miliseconds.
 
  my $timeout_ms = $multi->timeout();
 
-Calls L<curl_multi_timeout(3)|https://curl.haxx.se/libcurl/c/curl_multi_timeout.html>.
+Calls L<curl_multi_timeout(3)>.
 Throws L</Net::Curl::Multi::Code> on error.
 
 =item setopt( OPTION, VALUE )
@@ -138,7 +137,7 @@ VALUE depends on whatever that option expects.
 
  $multi->setopt( CURLMOPT_MAXCONNECTS, 10 );
 
-Calls L<curl_multi_setopt(3)|https://curl.haxx.se/libcurl/c/curl_multi_setopt.html>.
+Calls L<curl_multi_setopt(3)>.
 Throws L</Net::Curl::Multi::Code> on error.
 
 =item perform( )
@@ -148,33 +147,7 @@ or timeout has just reached zero.
 
  my $active = $multi->perform();
 
-Calls L<curl_multi_perform(3)|https://curl.haxx.se/libcurl/c/curl_multi_perform.html>.
-Rethrows exceptions from callbacks.
-Throws L</Net::Curl::Multi::Code> on error.
-
-=item wait( [OTHER_FDS], TIMEOUT_MS )
-
-This method polls on all file descriptors used by the curl easy handles contained in the given multi handle set.
-It will block until activity is detected on at least one of the handles or TIMEOUT_MS has passed.
-
- my $active = $multi->wait(1000);
-
-It will also poll on all filehandles requested. Each event descriptor is a hash and requires keys: fd - file number of the handle and events - a bitmask of the events to wait for. On detected event it will return the data in revents key.
-
- my $ev_read_stdin = {
-   fd => fileno STDIN,
-   events => CURL_WAIT_POLLIN,
- };
-
- my $active = $multi->wait( [ $ev_read_stdin ], 1000 );
- if ( $active and $ev_read_stdin->{revents} == CURL_WAIT_POLLIN )
- {
-   # STDIN is ready to read
-   ...
- }
-
-Calls L<curl_multi_wait(3)|https://curl.haxx.se/libcurl/c/curl_multi_wait.html>
-(L<available since libcurl/7.28.0|http://curl.haxx.se/libcurl/c/curl_multi_wait.html>).
+Calls L<curl_multi_perform(3)>.
 Rethrows exceptions from callbacks.
 Throws L</Net::Curl::Multi::Code> on error.
 
@@ -187,7 +160,7 @@ Signalize action on a socket.
  # there is data to read on socket:
  my $active = $multi->socket_action( $socket, CURL_CSELECT_IN );
 
-Calls L<curl_multi_socket_action(3)|https://curl.haxx.se/libcurl/c/curl_multi_socket_action.html>.
+Calls L<curl_multi_socket_action(3)>.
 Rethrows exceptions from callbacks.
 Throws L</Net::Curl::Multi::Code> on error.
 
@@ -201,7 +174,7 @@ specified. The value is used only in socket callback.
  # store socket object for socket callback
  $multi->assign( $socket->fileno(), $socket );
 
-Calls L<curl_multi_assign(3)|https://curl.haxx.se/libcurl/c/curl_multi_assign.html>.
+Calls L<curl_multi_assign(3)>.
 Throws L</Net::Curl::Multi::Code> on error.
 
 =item handles( )
@@ -225,7 +198,7 @@ Return a string for error code CODE.
 
  my $message = $multi->strerror( CURLM_BAD_EASY_HANDLE );
 
-See L<curl_multi_strerror(3)|https://curl.haxx.se/libcurl/c/curl_multi_strerror.html> for more info.
+See L<curl_multi_strerror(3)> for more info.
 
 =back
 
@@ -269,7 +242,7 @@ Socket callback will be called only if socket_action() method is being used.
 It receives 6 arguments: multi handle, easy handle, socket file number, poll
 action, socket data (see assign), and CURLMOPT_SOCKETDATA value. It must
 return 0.
-For more information refer to L<curl_multi_socket_action(3)|https://curl.haxx.se/libcurl/c/curl_multi_socket_action.html>.
+For more information refer to L<curl_multi_socket_action(3)>.
 
  sub cb_socket {
      my ( $multi, $easy, $socketfn, $action, $socketdata, $uservar ) = @_;
@@ -321,11 +294,9 @@ L<libcurl-errors(3)>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2011-2015 Przemyslaw Iskra <sparky at pld-linux.org>.
+Copyright (c) 2011 Przemyslaw Iskra <sparky at pld-linux.org>.
 
 You may opt to use, copy, modify, merge, publish, distribute and/or sell
 copies of the Software, and permit persons to whom the Software is furnished
 to do so, under the terms of the MPL or the MIT/X-derivate licenses. You may
 pick one of these licenses.
-
-=cut
