@@ -5,12 +5,11 @@ use warnings;
 use Net::Curl ();
 use Exporter 'import';
 
-our $VERSION = '0.58_3';
+*VERSION = \*Net::Curl::VERSION;
 
-our @EXPORT_OK = grep { /^CURL/x } keys %{Net::Curl::Share::};
+our @EXPORT_OK = grep /^CURL/, keys %{Net::Curl::Share::};
 our %EXPORT_TAGS = ( constants => \@EXPORT_OK );
 
-## no critic (ProhibitMultiplePackages)
 package Net::Curl::Share::Code;
 
 use overload
@@ -63,7 +62,7 @@ object.
 
  my $share = Net::Curl::Share->new( [qw(my very private data)] );
 
-Calls L<curl_share_init(3)|https://curl.haxx.se/libcurl/c/curl_share_init.html>.
+Calls L<curl_share_init(3)>.
 
 =back
 
@@ -78,7 +77,7 @@ VALUE depends on whatever that option expects.
 
  $share->setopt( CURLSHOPT_SHARE, CURL_LOCK_DATA_COOKIE );
 
-Calls L<curl_share_setopt(3)|https://curl.haxx.se/libcurl/c/curl_share_setopt.html>.
+Calls L<curl_share_setopt(3)>.
 Throws L</Net::Curl::Share::Code> on error.
 
 =back
@@ -95,7 +94,7 @@ Return a string for error code CODE.
 
  my $message = Net::Curl::Share::strerror( CURLSHE_BAD_OPTION );
 
-See L<curl_share_strerror(3)|https://curl.haxx.se/libcurl/c/curl_share_strerror.html> for more info.
+See L<curl_share_strerror(3)> for more info.
 
 =back
 
@@ -154,11 +153,9 @@ L<libcurl-errors(3)>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2011-2015 Przemyslaw Iskra <sparky at pld-linux.org>.
+Copyright (c) 2011 Przemyslaw Iskra <sparky at pld-linux.org>.
 
 You may opt to use, copy, modify, merge, publish, distribute and/or sell
 copies of the Software, and permit persons to whom the Software is furnished
 to do so, under the terms of the MPL or the MIT/X-derivate licenses. You may
 pick one of these licenses.
-
-=cut
